@@ -358,7 +358,119 @@ root:   $CWD/testdata/testmod
 dir:    $CWD/testdata/testmod/cycle
 display:./cycle
 files:
-    $CWD/testdata/testmod/cycle/cycle.cue`}}
+    $CWD/testdata/testmod/cycle/cycle.cue`}, {
+		name: "AcceptLegacyModuleWithLegacyModule",
+		cfg: &Config{
+			Dir:                 testdata("testmod_legacy"),
+			AcceptLegacyModules: true,
+		},
+		want: `path:   test.example/foo@v0
+module: test.example/foo@v0
+root:   $CWD/testdata/testmod_legacy
+dir:    $CWD/testdata/testmod_legacy
+display:.
+files:
+    $CWD/testdata/testmod_legacy/foo.cue`}, {
+		name: "AcceptLegacyModuleWithNonLegacyModule",
+		cfg: &Config{
+			Dir:                 testdataDir,
+			Tools:               true,
+			AcceptLegacyModules: true,
+		},
+		args: []string{"./imports"},
+		want: `path:   mod.test/test/imports@v0
+module: mod.test/test@v0
+root:   $CWD/testdata/testmod
+dir:    $CWD/testdata/testmod/imports
+display:./imports
+files:
+    $CWD/testdata/testmod/imports/imports.cue
+imports:
+    mod.test/catch: $CWD/testdata/testmod/cue.mod/pkg/mod.test/catch/catch.cue
+    mod.test/helper:helper1: $CWD/testdata/testmod/cue.mod/pkg/mod.test/helper/helper1.cue`}, {
+		name: "MismatchedModulePathInConfig",
+		cfg: &Config{
+			Dir:    testdataDir,
+			Tools:  true,
+			Module: "wrong.test@v0",
+		},
+		args: []string{"./imports"},
+		want: `err:    inconsistent modules: got "mod.test/test@v0", want "wrong.test@v0"
+path:   ""
+module: wrong.test@v0
+root:   ""
+dir:    ""
+display:""`}, {
+		name: "ModulePathInConfigWithoutMajorVersion",
+		cfg: &Config{
+			Dir:    testdataDir,
+			Tools:  true,
+			Module: "mod.test/test",
+		},
+		args: []string{"./imports"},
+		want: `err:    inconsistent modules: got "mod.test/test@v0", want "mod.test/test"
+path:   ""
+module: mod.test/test
+root:   ""
+dir:    ""
+display:""`}, {
+		name: "ModulePathInConfigWithoutMajorVersionAndMismatchedPath",
+		cfg: &Config{
+			Dir:    testdataDir,
+			Tools:  true,
+			Module: "mod.test/wrong",
+		},
+		args: []string{"./imports"},
+		want: `err:    inconsistent modules: got "mod.test/test@v0", want "mod.test/wrong"
+path:   ""
+module: mod.test/wrong
+root:   ""
+dir:    ""
+display:""`}, {
+		name: "ExplicitPackageWithUnqualifiedImportPath#1",
+		cfg: &Config{
+			Dir:     filepath.Join(testdataDir, "multi"),
+			Package: "main",
+		},
+		args: []string{"."},
+		want: `path:   mod.test/test/multi@v0:main
+module: mod.test/test@v0
+root:   $CWD/testdata/testmod
+dir:    $CWD/testdata/testmod/multi
+display:.
+files:
+    $CWD/testdata/testmod/multi/file.cue`}, {
+		name: "ExplicitPackageWithUnqualifiedImportPath#2",
+		// This test replicates the failure reported in https://cuelang.org/issue/3213
+		cfg: &Config{
+			Dir:     filepath.Join(testdataDir, "multi2"),
+			Package: "other",
+		},
+		args: []string{"."},
+		want: `path:   mod.test/test/multi2@v0:other
+module: mod.test/test@v0
+root:   $CWD/testdata/testmod
+dir:    $CWD/testdata/testmod/multi2
+display:.
+files:
+    $CWD/testdata/testmod/multi2/other.cue
+imports:
+    mod.test/test/sub: $CWD/testdata/testmod/sub/sub.cue`}, {
+		name: "ExplicitPackageWithUnqualifiedImportPath#3",
+		cfg: &Config{
+			Dir:     filepath.Join(testdataDir, "multi3"),
+			Package: "other",
+		},
+		args: []string{"."},
+		want: `path:   mod.test/test/multi3@v0:other
+module: mod.test/test@v0
+root:   $CWD/testdata/testmod
+dir:    $CWD/testdata/testmod/multi3
+display:.
+files:
+    $CWD/testdata/testmod/multi3/other.cue
+imports:
+    mod.test/test/sub: $CWD/testdata/testmod/sub/sub.cue`}}
 	tdtest.Run(t, testCases, func(t *tdtest.T, tc *loadTest) {
 		pkgs := Instances(tc.args, tc.cfg)
 
